@@ -6,6 +6,7 @@ from .contexts import (
 )
 from .handlers import (
     CommandHandler,
+    CommandsHandler,
     CompositeHandler,
     InlineMenuHandler,
     MessageHandler,
@@ -32,6 +33,7 @@ __all__ = [
     "StartHandler",
     "StartGroupHandler",
     "InlineMenuHandler",
+    "CommandsHandler",
     "UpdateContext",
     "QueryContext",
     "TextContext",
