@@ -1,16 +1,7 @@
-from botty_core import Callback, Context
-from botty_core.types import Chat, Message, ReplyMarkup, User
+from botty_core import Callback, Chat, Context, Message, ReplyMarkup, User
 
 
 class UpdateContext(Context):
-    async def reply(
-        self,
-        text: str,
-        markup: ReplyMarkup | None = None,
-    ) -> Message:
-        raw = await self.message.reply(text, markup)
-        return Message(raw)
-
     @property
     def message(self) -> Message:
         return self.effective_message
@@ -23,5 +14,13 @@ class UpdateContext(Context):
     def chat(self) -> Chat:
         return self.effective_chat
 
+    async def reply(
+        self,
+        text: str,
+        markup: ReplyMarkup | None = None,
+    ) -> Message:
+        raw = await self.message.reply(text, markup)
+        return Message(raw)
+
 
 UpdateCallback = Callback[UpdateContext]
