@@ -1,8 +1,12 @@
+from collections.abc import Mapping
+
 from botty_core import PTBContext
 from telegram import Update, ext
 
 from botty.contexts import TextCallback, TextContext
 
+from .composite import CompositeHandler
+
 
 class CommandHandler(ext.CommandHandler[PTBContext]):
     filters: ext.filters.BaseFilter = ext.filters.UpdateType.MESSAGE
@@ -14,3 +18,11 @@ class CommandHandler(ext.CommandHandler[PTBContext]):
     async def handle(self, update: Update, _context: PTBContext) -> None:
         context = TextContext(_context, update)
         await self._callback(context)
+
+
+class CommandsHandler(CompositeHandler):
+    def __init__(self, handlers: Mapping[str, TextCallback]) -> None:
+        subhandlers = [
+            CommandHandler(button, handler) for button, handler in handlers.items()
+        ]
+        super().__init__(*subhandlers)
